
# Rocketlane MCP Server

An MCP Server for the Rocketlane API.

## Supported Integrations

- AgentR
- API Key (Coming Soon)
- OAuth (Coming Soon)

## Tools

This is automatically generated from OpenAPI schema for the Rocketlane API.

## Supported Integrations

This tool can be integrated with any service that supports HTTP requests.

## Tool List

| Tool | Description |
|------|-------------|
| get_subscription | Retrieves subscription details from the server. |
| get_home | Retrieves the JSON response from the '/home' endpoint of the configured API. |
| get_all_projects | Retrieves a list of all projects from the remote service. |
| get_projects_by_projectid | Retrieves project details for a given project ID from the server. |
| get_projects_by_projectid_tasks | Retrieves a list of tasks associated with a given project ID. |
| create_task | Creates a new task within the specified project, assigning optional details such as description, name, assignee, start date, and due date. |



## Usage

- Login to AgentR
- Follow the quickstart guide to setup MCP Server for your client
- Visit Apps Store and enable the Rocketlane app
- Restart the MCP Server

### Local Development

- Follow the README to test with the local MCP Server
